# Transcriptor

## A transcription service wrapper that makes it easier to work with transcriptions.

Transcription services provide a cost effective way to add accessibility to
your audio, but are often a challenge to integrate into your systems.

Transcriptor aims to make working with transcriptions easier.

### Features:

- An object-oriented approach to Transcriptions, Markers, and Speakers
- Nondestructive manipulation of text and references.

## Supported Services

- Amazon Transcribe (boto3)

## Planned Support For

- Google Speech-To-Text
